<?php
/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function mighti_body_classes( $classes ) {
  // Adds a class of hfeed to non-singular pages.
  if ( ! is_singular() ) {
    $classes[] = 'hfeed';
  }
  return $classes;
}
add_filter( 'body_class', 'mighti_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function mighti_pingback_header() {
  if ( is_singular() && pings_open() ) {
    echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
  }
}

add_action( 'wp_head', 'mighti_pingback_header' );
/**  kses_allowed_html */
function mighti_prefix_kses_allowed_html($tags, $context) {
  switch($context) {
    case 'mighti': 
      $tags = array( 
        'a' => array('href' => array()),
        'b' => array()
      );
      return $tags;
    default: 
      return $tags;
  }
}
add_filter( 'wp_kses_allowed_html', 'mighti_prefix_kses_allowed_html', 10, 2);

/*
Register Fonts theme google font
*/
function mighti_studio_fonts_url() {
    $font_url = '';
    
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'mighti' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Hanken Grotesk:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,300;1,400;1,700&display=swap'), "//fonts.googleapis.com/css" );
    }
    return $font_url;
}


function mighti_studio_scripts() {
    wp_enqueue_style( 'studio-fonts', mighti_studio_fonts_url(), array(), '1.0.0' );
}
add_action( 'wp_enqueue_scripts', 'mighti_studio_scripts' );

//Favicon Icon
function mighti_site_icon() {
 if ( ! ( function_exists( 'has_site_icon' ) && has_site_icon() ) ) {     
    $mighti_option = get_option('mighti_option');
     
    if(!empty($mighti_option['rs_favicon']['url']))
    {?>
    <link rel="shortcut icon" type="image/x-icon" href="<?php echo esc_url(($mighti_option['rs_favicon']['url'])); ?>"> 
  <?php 
    }
  }
}
add_filter('wp_head', 'mighti_site_icon');


//excerpt for specific section
function mighti_wpex_get_excerpt( $args = array() ) {
  // Defaults
  $defaults = array(
    'post'            => '',
    'length'          => 48,
    'readmore'        => false,
    'readmore_text'   => esc_html__( 'read more', 'mighti' ),
    'readmore_after'  => '',
    'custom_excerpts' => true,
    'disable_more'    => false,
  );
  // Apply filters
  $defaults = apply_filters( 'mighti_wpex_get_excerpt_defaults', $defaults );
  // Parse args
  $args = wp_parse_args( $args, $defaults );
  // Apply filters to args
  $args = apply_filters( 'mighti_wpex_get_excerpt_args', $defaults );
  // Extract
  extract( $args );
  // Get global post data
  if ( ! $post ) {
    global $post;
  }

  $post_id = $post->ID;
  if ( $custom_excerpts && has_excerpt( $post_id ) ) {
    $output = $post->post_excerpt;
  } 
  else { 
    $readmore_link = '<a href="' . get_permalink( $post_id ) . '" class="readmore">' . $readmore_text . $readmore_after . '</a>';    
    if ( ! $disable_more && strpos( $post->post_content, '<!--more-->' ) ) {
      $output = apply_filters( 'the_content', get_the_content( $readmore_text . $readmore_after ) );
    }    
    else {     
      $output = wp_trim_words( strip_shortcodes( $post->post_content ), $length );      
      if ( $readmore ) {
        $output .= apply_filters( 'mighti_wpex_readmore_link', $readmore_link );
      }
    }
  }
  // Apply filters and echo
  return apply_filters( 'mighti_wpex_get_excerpt', $output );
}

//Demo content file include here

function mighti_import_files() {
  return array(
    array(
      'import_file_name'           => 'Mighti Default Demo',
      'categories'                 => array( 'Digital Agency' ),
      'import_file_url'            => 'https://themewant.com/products/demo-data/mighti/mighti-content.xml',
             
      'import_redux'               => array(
        array(
          'file_url'    => 'https://themewant.com/products/demo-data/mighti/mighti-options.json',
          'option_name' => 'mighti_option',
        ),
      ),

      'import_preview_image_url'   => 'https://html.themewant.com/mighty/landing/assets/images/demos/02.jpg',
     'import_notice'              => esc_html__( 'Caution: For importing demo data please click on "Import Demo Data" button. During demo data installation please do not refresh the page.', 'mighti' ),
      'preview_url'                => 'https://mighti.themewant.com/',     
      
    ),
    array(
      'import_file_name'           => 'Creative Agency',
      'categories'                 => array( 'Agency' ),
      'import_file_url'            => 'https://themewant.com/products/demo-data/mighti/creative/mighti-content.xml',
             
      'import_redux'               => array(
        array(
          'file_url'    => 'https://themewant.com/products/demo-data/mighti/creative/mighti-options.json',
          'option_name' => 'mighti_option',
        ),
      ),

      'import_preview_image_url'   => 'https://html.themewant.com/mighty/landing/assets/images/demos/03.jpg',
     'import_notice'              => esc_html__( 'Caution: For importing demo data please click on "Import Demo Data" button. During demo data installation please do not refresh the page.', 'mighti' ),
      'preview_url'                => 'https://mighti.themewant.com/creative-agency/',     
      
    ), 
    array(
      'import_file_name'           => 'Creative Portfolio',
      'categories'                 => array( 'Portfolio' ),
      'import_file_url'            => 'https://themewant.com/products/demo-data/mighti/corporate/mighti-content.xml',
             
      'import_redux'               => array(
        array(
          'file_url'    => 'https://themewant.com/products/demo-data/mighti/corporate/mighti-options.json',
          'option_name' => 'mighti_option',
        ),
      ),

      'import_preview_image_url'   => 'https://html.themewant.com/mighty/landing/assets/images/demos/05.jpg',
     'import_notice'              => esc_html__( 'Caution: For importing demo data please click on "Import Demo Data" button. During demo data installation please do not refresh the page.', 'mighti' ),
      'preview_url'                => 'https://mighti.themewant.com/creative-portfolio/',     
      
    ), 

    array(
      'import_file_name'           => 'Design Agency',
      'categories'                 => array( 'Agency' ),
      'import_file_url'            => 'https://themewant.com/products/demo-data/mighti/design/mighti-content.xml',
             
      'import_redux'               => array(
        array(
          'file_url'    => 'https://themewant.com/products/demo-data/mighti/design/mighti-options.json',
          'option_name' => 'mighti_option',
        ),
      ),

      'import_preview_image_url'   => 'https://html.themewant.com/mighty/landing/assets/images/demos/04.jpg',
     'import_notice'              => esc_html__( 'Caution: For importing demo data please click on "Import Demo Data" button. During demo data installation please do not refresh the page.', 'mighti' ),
      'preview_url'                => 'https://mighti.themewant.com/design-agency/',     
      
    ), 
    //building
    array(
      'import_file_name'           => 'Personal Portfolio',
      'categories'                 => array( 'Portfolio' ),
      'import_file_url'            => 'https://themewant.com/products/demo-data/mighti/portfolio/mighti-content.xml',
             
      'import_redux'               => array(
        array(
          'file_url'    => 'https://themewant.com/products/demo-data/mighti/portfolio/mighti-options.json',
          'option_name' => 'mighti_option',
        ),
      ),

      'import_preview_image_url'   => 'https://html.themewant.com/mighty/landing/assets/images/demos/01.jpg',
     'import_notice'              => esc_html__( 'Caution: For importing demo data please click on "Import Demo Data" button. During demo data installation please do not refresh the page.', 'mighti' ),
      'preview_url'                => 'https://mighti.themewant.com/personal-portfolio/',     
      
    ), 
    //architecute
    array(
      'import_file_name'           => 'Business Agency',
      'categories'                 => array( 'Agency' ),
      'import_file_url'            => 'https://themewant.com/products/demo-data/mighti/business/mighti-content.xml',
             
      'import_redux'               => array(
        array(
          'file_url'    => 'https://themewant.com/products/demo-data/mighti/business/mighti-options.json',
          'option_name' => 'mighti_option',
        ),
      ),

      'import_preview_image_url'   => 'https://html.themewant.com/mighty/landing/assets/images/demos/31.jpg',
     'import_notice'              => esc_html__( 'Caution: For importing demo data please click on "Import Demo Data" button. During demo data installation please do not refresh the page.', 'mighti' ),
      'preview_url'                => 'https://mighti.themewant.com/business-agency/',     
      
    ),    

    
  );
}

add_filter( 'pt-ocdi/import_files', 'mighti_import_files' );

function mighti_after_import_setup($selected_import) {
  // Assign menus to their locations.
	$main_menu     = get_term_by( 'name', 'Primary Menu', 'nav_menu' );

	set_theme_mod( 'nav_menu_locations', array(
      'menu-1' => $main_menu->term_id,          
    )
  );
  if ( 'Mighti Default Demo' == $selected_import['import_file_name'] ) {
    $front_page_id = get_page_by_title('Digital Agency');
  }

  if ( 'Creative Agency' == $selected_import['import_file_name'] ) {
    $front_page_id = get_page_by_title('Creative Agency');
  }

  if ( 'Business Agency' == $selected_import['import_file_name'] ) {
    $front_page_id = get_page_by_title('Business Agency');
  }

  if ( 'Creative Portfolio' == $selected_import['import_file_name'] ) {
    $front_page_id = get_page_by_title('Creative Portfolio');
  }

  if ( 'Personal Portfolio' == $selected_import['import_file_name'] ) {
    $front_page_id = get_page_by_title('Personal Portfolio');
  }

  if ( 'Design Agency' == $selected_import['import_file_name'] ) {
    $front_page_id = get_page_by_title('Design Agency');
  }
  
  $blog_page_id  = get_page_by_title( 'Blog' );
  update_option( 'show_on_front', 'page' );
  update_option( 'page_on_front', $front_page_id->ID );
  update_option( 'page_for_posts', $blog_page_id->ID ); 

  //Import Revolution Slider
  //Import Revolution Slider
  if ( class_exists( 'RevSlider' ) ) {
    $slider_array = array(
      get_template_directory()."/inc/demo-data/sliders/business-agency.zip",                          
      get_template_directory()."/inc/demo-data/sliders/creative-agency.zip",
      get_template_directory()."/inc/demo-data/sliders/full-screen-showcase-11.zip",                          
    );

    $slider = new RevSlider();
    foreach($slider_array as $filepath){
      $slider->importSliderFromPost(true,true,$filepath);  
    }
  } 
 
  
}
add_action( 'pt-ocdi/after_import', 'mighti_after_import_setup' );

add_filter( 'use_widgets_block_editor', '__return_false' );

function mighti_mime_types($mimes) {
  $mimes['svg'] = 'image/svg+xml';
  return $mimes;
}
add_filter('upload_mimes', 'mighti_mime_types');

update_option('elementor_disable_color_schemes', 'yes');
update_option('elementor_disable_typography_schemes', 'yes');

//added elementor support for custom post type
function mighti_enable_elementor_for_custom_post_type() {
  add_post_type_support( 'rt-portfolios', 'elementor' );
  add_post_type_support( 'rts-canvans', 'elementor' );
  add_post_type_support( 'rtelements_pro', 'elementor' );
  add_post_type_support( 'services', 'elementor' );
}
add_action( 'init', 'mighti_enable_elementor_for_custom_post_type' );